@@ -323,3 +323,55 @@ plot_crayons <-
 
     text(x+dx*1.2, y, names(crayons)[ord], cex=cex, adj=c(0, 0.5))
 }
+
+#' Crayon colors
+#'
+#' Vector of colors corresponding to Crayola crayons
+#'
+#' @param color_names Optional vector of color names; can be partial matches.
+#' @param ... Additional optional color names
+#'
+#' @return Vector of named RGB colors
+#'
+#' @references \url{http://en.wikipedia.org/wiki/List_of_Crayola_crayon_colors}
+#'
+#' @seealso \code{\link{plot_crayons}}, \code{\link{brocolors}}
+#' @export
+#' @keywords utilities
+crayons <-
+    function(color_names=NULL, ...)
+{
+    crayons <- brocolors("crayons")
+    if(is.null(color_names)) return(crayons)
+
+    dots <- list(...)
+    color_names <- unlist(c(color_names,dots))
+
+    allnames <- names(crayons)
+
+    # look for exact matches
+    m <- match(color_names, allnames)
+
+    # items not found: do grep
+    #    require exactly one match
+    notfound <- color_names[is.na(m)]
+    g <- vapply(notfound, function(a) {
+        z <- grep(a, allnames, ignore.case=TRUE)
+        if(length(z) < 1) return(-1) # not found
+        if(length(z) > 1) return(-2) # found multiply
+        z }, 1)
+
+    # issue warning if some not found or some found multiply
+    if(any(g < 0)) {
+        if(any(g == -1)) warning("Some colors not found")
+        if(any(g == -2)) warning("Some colors with multiple matches")
+    }
+    g[g < 0] <- NA
+    m[is.na(m)] <- g
+
+    result <- crayons[g]
+    # for those not found singly, add input as names
+    names(result)[is.na(g)] <- color_names[is.na(g)]
+
+    result
+}
